@@ -26,26 +26,13 @@
 // Qt
 #include <QObject>
 
-struct LauncherClientPrivate;
 /**
  * Makes it easy for unity-2d components to communicate with unity-2d-launcher
  */
-class LauncherClient : public QObject
+class LauncherClient
 {
-    Q_OBJECT
 public:
-    // The amount of pixels used by the launcher on the left edge when it is
-    // fully visible.
     static const int MaximumWidth;
-
-    LauncherClient(QObject* parent = 0);
-    ~LauncherClient();
-
-    void beginForceVisible();
-    void endForceVisible();
-
-private:
-    LauncherClientPrivate* const d;
 };
 
 #endif /* LAUNCHERCLIENT_H */
