@@ -41,6 +41,14 @@
 #include <gtk/gtk.h>
 #include <pango/pango.h>
 
+// Testability
+#include <QtPlugin>
+#include <QPluginLoader>
+#include <QLibraryInfo>
+
+// libc
+#include <stdlib.h>
+
 ///////////////////////////////
 class PlatformFontTracker
 {
@@ -101,11 +109,14 @@ static bool arrayContains(char** begin, char** end, const char* string)
     return false;
 }
 
-QAccessibleInterface *panelFactory(const QString &classname, QObject *object)
+QAccessibleInterface *accessibilityFactory(const QString &classname, QObject *object)
 {
     QAccessibleInterface *interface = 0;
 
-    if (classname == "Unity2dPanel" && object && object->isWidgetType()) {
+    if (classname == "ShellDeclarativeView" && object && object->isWidgetType()) {
+        interface = new QAccessibleWidget(static_cast<QWidget *>(object), QAccessible::Pane);
+    }
+    else if (classname == "Unity2dPanel" && object && object->isWidgetType()) {
         interface = new QAccessibleWidget(static_cast<QWidget *>(object), QAccessible::ToolBar);
     }
 
@@ -133,6 +144,14 @@ void Unity2dApplication::earlySetup(int& argc, char** argv)
         QApplication::setGraphicsSystem("raster");
     }
 
+    /* We have these if we were DBus activated, but we don't want our child
+     * processes to inherit them
+     *
+     * https://launchpad.net/bugs/873027
+     */
+    unsetenv("DBUS_STARTER_ADDRESS");
+    unsetenv("DBUS_STARTER_BUS_TYPE");
+
     /* Unless style has been specified in args, set default Qt style to
      * QWindowStyle to avoid loading QGtkStyle. We don't want to load QGtkStyle
      * because it uses libgtk2, which causes conflicts with our gtk3 code.
@@ -148,6 +167,9 @@ Unity2dApplication::Unity2dApplication(int& argc, char** argv)
 {
     /* Configure translations */
     Unity2dTr::init("unity-2d", INSTALL_PREFIX "/share/locale");
+
+    /* TRANSLATORS: This refers to the direction of text
+       (left-to-right or right-to-left): possible values are LTR or RTL */
     if (u2dTr("QT_LAYOUT_DIRECTION") == "RTL") {
         QApplication::setLayoutDirection(Qt::RightToLeft);
     }
@@ -160,7 +182,7 @@ Unity2dApplication::Unity2dApplication(int& argc, char** argv)
         qputenv("GSETTINGS_SCHEMA_DIR", unity2dDirectory().toLocal8Bit() + "/data");
     }
 
-    QAccessible::installFactory(panelFactory);
+    QAccessible::installFactory(accessibilityFactory);
 }
 
 Unity2dApplication::~Unity2dApplication()
