@@ -21,6 +21,7 @@
 
 // Self
 #include "unity2dpanel.h"
+#include "strutmanager.h"
 #include <debug_p.h>
 #include <indicatorsmanager.h>
 
@@ -32,9 +33,9 @@
 #include <QHBoxLayout>
 #include <QX11Info>
 
-// X
-#include <X11/Xlib.h>
-#include <X11/Xatom.h>
+// unity-2d
+#include "panelpalettemanager.h"
+#include "screeninfo.h"
 
 static const int SLIDE_DURATION = 125;
 
@@ -44,76 +45,25 @@ struct Unity2dPanelPrivate
     Unity2dPanel::Edge m_edge;
     mutable IndicatorsManager* m_indicatorsManager;
     QHBoxLayout* m_layout;
-    QPropertyAnimation* m_slideInAnimation;
-    QPropertyAnimation* m_slideOutAnimation;
-    bool m_useStrut;
-    int m_delta;
-    bool m_manualSliding;
-
-    void setStrut(ulong* struts)
-    {
-        static Atom atom = XInternAtom(QX11Info::display(), "_NET_WM_STRUT_PARTIAL", False);
-        XChangeProperty(QX11Info::display(), q->effectiveWinId(), atom,
-                        XA_CARDINAL, 32, PropModeReplace,
-                        (unsigned char *) struts, 12);
-    }
-
-    void reserveStrut()
-    {
-        QDesktopWidget* desktop = QApplication::desktop();
-        const QRect screen = desktop->screenGeometry(q);
-        const QRect available = desktop->availableGeometry(q);
-
-        ulong struts[12] = {};
-        switch (m_edge) {
-        case Unity2dPanel::LeftEdge:
-            if (QApplication::isLeftToRight()) {
-                struts[0] = q->width();
-                struts[4] = available.top();
-                struts[5] = available.y() + available.height();
-            } else {
-                struts[1] = q->width();
-                struts[6] = available.top();
-                struts[7] = available.y() + available.height();
-            }
-            break;
-        case Unity2dPanel::TopEdge:
-            struts[2] = q->height();
-            struts[8] = screen.left();
-            struts[9] = screen.x() + screen.width();
-            break;
-        }
-
-        setStrut(struts);
-    }
-
-    void releaseStrut()
-    {
-        ulong struts[12];
-        memset(struts, 0, sizeof struts);
-        setStrut(struts);
-    }
+    StrutManager m_strutManager;
+    ScreenInfo* m_screenInfo;
 
     void updateGeometry()
     {
-        QDesktopWidget* desktop = QApplication::desktop();
-        const QRect screen = desktop->screenGeometry(q);
-        const QRect available = desktop->availableGeometry(q);
+        const QRect screen = m_screenInfo->geometry();
+        const QRect available = m_screenInfo->availableGeometry();
 
         QRect rect;
         switch (m_edge) {
         case Unity2dPanel::LeftEdge:
             if (QApplication::isLeftToRight()) {
                 rect = QRect(screen.left(), available.top(), q->width(), available.height());
-                rect.moveLeft(m_delta);
             } else {
                 rect = QRect(screen.right() - q->width(), available.top(), q->width(), available.height());
-                rect.moveRight(screen.right() - m_delta);
             }
             break;
         case Unity2dPanel::TopEdge:
             rect = QRect(screen.left(), screen.top(), screen.width(), q->height());
-            rect.moveTop(m_delta);
             break;
         }
 
@@ -136,42 +86,35 @@ struct Unity2dPanelPrivate
 
     void updateEdge()
     {
-        if (m_useStrut) {
-            reserveStrut();
-        }
         updateGeometry();
         updateLayoutDirection();
     }
 };
 
-Unity2dPanel::Unity2dPanel(bool requiresTransparency, QWidget* parent)
+Unity2dPanel::Unity2dPanel(bool requiresTransparency, int screen, ScreenInfo::Corner corner, QWidget* parent)
 : QWidget(parent)
 , d(new Unity2dPanelPrivate)
 {
+    d->m_strutManager.setWidget(this);
+    d->m_strutManager.setEdge(Unity2dPanel::TopEdge);
     d->q = this;
     d->m_edge = Unity2dPanel::TopEdge;
     d->m_indicatorsManager = 0;
-    d->m_useStrut = true;
-    d->m_delta = 0;
-    d->m_manualSliding = false;
     d->m_layout = new QHBoxLayout(this);
     d->m_layout->setMargin(0);
     d->m_layout->setSpacing(0);
-
-    d->m_slideInAnimation = new QPropertyAnimation(this);
-    d->m_slideInAnimation->setTargetObject(this);
-    d->m_slideInAnimation->setPropertyName("delta");
-    d->m_slideInAnimation->setDuration(SLIDE_DURATION);
-    d->m_slideInAnimation->setEndValue(0);
-
-    d->m_slideOutAnimation = new QPropertyAnimation(this);
-    d->m_slideOutAnimation->setTargetObject(this);
-    d->m_slideOutAnimation->setPropertyName("delta");
-    d->m_slideOutAnimation->setDuration(SLIDE_DURATION);
-    d->m_slideOutAnimation->setEndValue(-panelSize());
+    if (corner != ScreenInfo::InvalidCorner) {
+        d->m_screenInfo = new ScreenInfo(corner, this);
+    } else if (screen >= 0) {
+        d->m_screenInfo = new ScreenInfo(screen, this);
+    } else {
+        d->m_screenInfo = new ScreenInfo(this, this);
+    }
+    new Unity2d::PanelPaletteManager(this);
 
     setAttribute(Qt::WA_X11NetWmWindowTypeDock);
     setAttribute(Qt::WA_Hover);
+    setObjectName(QString::number(screen));
 
     if (QX11Info::isCompositingManagerRunning() && requiresTransparency) {
         setAttribute(Qt::WA_TranslucentBackground);
@@ -180,19 +123,18 @@ Unity2dPanel::Unity2dPanel(bool requiresTransparency, QWidget* parent)
     }
     
     connect(QApplication::desktop(), SIGNAL(workAreaResized(int)), SLOT(slotWorkAreaResized(int)));
+    connect(&d->m_strutManager, SIGNAL(enabledChanged(bool)), SIGNAL(useStrutChanged(bool)));
 }
 
 Unity2dPanel::~Unity2dPanel()
 {
-    if (d->m_useStrut) {
-        d->releaseStrut();
-    }
     delete d;
 }
 
 void Unity2dPanel::setEdge(Unity2dPanel::Edge edge)
 {
     d->m_edge = edge;
+    d->m_strutManager.setEdge(edge);
     if (isVisible()) {
         d->updateEdge();
     }
@@ -203,11 +145,23 @@ Unity2dPanel::Edge Unity2dPanel::edge() const
     return d->m_edge;
 }
 
+void Unity2dPanel::setScreen(int screen)
+{
+    d->m_screenInfo->setScreen(screen);
+    setObjectName(QString::number(screen));
+}
+
+int Unity2dPanel::screen() const
+{
+    return d->m_screenInfo->screen();
+}
+
 IndicatorsManager* Unity2dPanel::indicatorsManager() const
 {
-    if (d->m_indicatorsManager == 0)
-        d->m_indicatorsManager =
-            new IndicatorsManager(const_cast<Unity2dPanel*>(this));
+    if (d->m_indicatorsManager == 0) {
+        auto const_this = const_cast<Unity2dPanel*>(this);
+        d->m_indicatorsManager = new IndicatorsManager(const_this, const_this);
+    }
 
     return d->m_indicatorsManager;
 }
@@ -216,13 +170,6 @@ void Unity2dPanel::showEvent(QShowEvent* event)
 {
     QWidget::showEvent(event);
     d->updateEdge();
-    d->m_slideOutAnimation->setEndValue(-panelSize());
-}
-
-void Unity2dPanel::resizeEvent(QResizeEvent* event)
-{
-    QWidget::resizeEvent(event);
-    d->m_slideOutAnimation->setEndValue(-panelSize());
 }
 
 void Unity2dPanel::slotWorkAreaResized(int screen)
@@ -252,35 +199,12 @@ void Unity2dPanel::addSpacer()
 
 bool Unity2dPanel::useStrut() const
 {
-    return d->m_useStrut;
+    return d->m_strutManager.enabled();
 }
 
 void Unity2dPanel::setUseStrut(bool value)
 {
-    if (d->m_useStrut != value) {
-        if (value) {
-            d->reserveStrut();
-        } else {
-            d->releaseStrut();
-        }
-        d->m_useStrut = value;
-        Q_EMIT useStrutChanged(value);
-    }
-}
-
-int Unity2dPanel::delta() const
-{
-    return d->m_delta;
-}
-
-void Unity2dPanel::setDelta(int delta)
-{
-    /* Clamp delta to be between 0 and minus its size */
-    int minDelta = -panelSize();
-    int maxDelta = 0;
-
-    d->m_delta = qMax(qMin(delta, maxDelta), minDelta);
-    d->updateGeometry();
+    d->m_strutManager.setEnabled(value);
 }
 
 int Unity2dPanel::panelSize() const
@@ -288,39 +212,10 @@ int Unity2dPanel::panelSize() const
     return (d->m_edge == Unity2dPanel::TopEdge) ? height() : width();
 }
 
-void Unity2dPanel::slideIn()
+QString Unity2dPanel::id() const
 {
-    d->m_slideOutAnimation->stop();
-    if (d->m_slideInAnimation->state() != QAbstractAnimation::Running) {
-        d->m_slideInAnimation->setStartValue(d->m_delta);
-        d->m_slideInAnimation->start();
-    }
-}
-
-void Unity2dPanel::slideOut()
-{
-    d->m_slideInAnimation->stop();
-    if (d->m_slideOutAnimation->state() != QAbstractAnimation::Running) {
-        d->m_slideOutAnimation->setStartValue(d->m_delta);
-        d->m_slideOutAnimation->start();
-    }
-}
-
-bool Unity2dPanel::manualSliding() const
-{
-    return d->m_manualSliding;
-}
-
-void Unity2dPanel::setManualSliding(bool manualSliding)
-{
-    if (d->m_manualSliding != manualSliding) {
-        d->m_manualSliding = manualSliding;
-        if (manualSliding) {
-            d->m_slideInAnimation->stop();
-            d->m_slideOutAnimation->stop();
-        }
-        Q_EMIT manualSlidingChanged(d->m_manualSliding);
-    }
+    int screen = QApplication::desktop()->screenNumber(this);
+    return "Unity2DPanel" + QString::number(screen);
 }
 
 #include "unity2dpanel.moc"
