@@ -253,7 +253,7 @@ struct AppNameAppletPrivate
 
     void setupWindowHelper()
     {
-        m_windowHelper = new WindowHelper(q->panel()->screen(), q);
+        m_windowHelper = new WindowHelper(q->panel(), q);
         QObject::connect(m_windowHelper, SIGNAL(stateChanged()),
             q, SLOT(updateWidgets()));
         QObject::connect(m_windowHelper, SIGNAL(nameChanged()),
@@ -392,8 +392,10 @@ void AppNameApplet::leaveEvent(QEvent*) {
     updateWidgets();
 }
 
-void AppNameApplet::mouseDoubleClickEvent(QMouseEvent*) {
-    d->m_windowHelper->unmaximize();
+void AppNameApplet::mouseDoubleClickEvent(QMouseEvent* event) {
+    if (event->button() == Qt::LeftButton) {
+        d->m_windowHelper->unmaximize();
+    }
 }
 
 void AppNameApplet::mousePressEvent(QMouseEvent* event) {
